aboutsummaryrefslogtreecommitdiffstats
path: root/bug/interface.go
diff options
context:
space:
mode:
Diffstat (limited to 'bug/interface.go')
-rw-r--r--bug/interface.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/bug/interface.go b/bug/interface.go
index c397bfbc..72dee61c 100644
--- a/bug/interface.go
+++ b/bug/interface.go
@@ -12,8 +12,8 @@ type Interface interface {
// HumanId return the Bug identifier truncated for human consumption
HumanId() string
- // IsValid check if the Bug data is valid
- IsValid() bool
+ // Validate check if the Bug data is valid
+ Validate() error
// Append an operation into the staging area, to be committed later
Append(op Operation)